#
# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
#

"""TODO: Add module docstring."""

from pyvider.common.utils.attrs_factory import create_attrs_class_from_schema
from pyvider.common.utils.availability import HAS_MSGPACK

__all__ = ["HAS_MSGPACK", "create_attrs_class_from_schema"]

# 🐍🏗️🔚
